@@ -7,6 +7,6 @@ admin.autodiscover()
 urlpatterns = patterns(
     '',
     url(r'^$', RedirectView.as_view(url='/statistic/all_time/'), name='redirecto-all-time-statistic'),
-    url(r'^statistic/', include('statistic.urls')),
+    url(r'^statistic/', include('pingokio.statistic.urls')),
     url(r'^admin/', include(admin.site.urls)),
 )
